@@ -3,11 +3,11 @@
 ROOT=$(cd "$(dirname "$0")/../" && pwd)
 
 if [[ $# -eq 0 ]]; then
-    $0 5.26.3 5-26
-    $0 5.28.3 5-28
-    $0 5.30.3 5-30
-    $0 5.32.1 5-32
     $0 5.34.0 5-34
+    $0 5.32.1 5-32
+    $0 5.30.3 5-30
+    $0 5.28.3 5-28
+    $0 5.26.3 5-26
     exit 0
 fi
 
@@ -20,13 +20,13 @@ set -uex
 # clean up
 rm -rf "$OPT"
 mkdir -p "$OPT/lib/perl5/site_perl"
-rm -f "$DIST/perl-$TAG-paws.zip"
+rm -f "$DIST/perl-$TAG-paws-x86_64.zip"
 
 docker run --rm \
     -v "$ROOT:/var/task" \
     -v "$OPT/lib/perl5/site_perl:/opt/lib/perl5/site_perl" \
-    lambci/lambda:build-provided \
+    public.ecr.aws/sam/build-provided:latest \
     ./author/build-paws.sh "$TAG"
 cd "$OPT"
 mkdir -p "$DIST"
-zip -9 -r "$DIST/perl-$TAG-paws.zip" .
+zip -9 -r "$DIST/perl-$TAG-paws-x86_64.zip" .
